@@ -9,7 +9,7 @@ def run_script(script_list , out_folder = '', out_prefix = None): #, email_sende
   logs_out = []
 
   # Create Directory if not exists
-  if not os.path.exists(out_folder) :
+  if (not os.path.exists(out_folder)) & (out_folder != '') :
     os.mkdir(out_folder)
 
   # Execute Python Part
@@ -40,16 +40,17 @@ def run_script(script_list , out_folder = '', out_prefix = None): #, email_sende
   
   return pd.DataFrame(logs_out, columns = ['start','script','notebook_out','run_result','end'])
 
-def run_pipeline(script_list, out_folder = '', out_prefix = None, email_dict = {} , sending = True
-                    , only_error = False, notebook_attached = False, attached_only_error = True, attached_log = False, log_sql = None) :
+def run_pipeline(script_list = [], out_folder = '', out_prefix = None, email_dict = None , sending = False
+                    , only_error = False, notebook_attached = False, attached_only_error = False, attached_log = False, log_sql = None) :
 
     if sending :
-        if ['user' , 'password', 'server' ,'sendto','subject'].sort() != list(email_dict.keys()).sort() :
+        if (['user' , 'password', 'server' ,'sendto','subject'].sort() != list(email_dict.keys()).sort()) or (email_dict == None) :
             raise Exception("email_dict parameter must have 'user' , 'password' , 'server' , 'sendto' , 'subject' ")
 
         run_output = 'Start Job at ' + str(datetime.now()) + '<br>' + '<br>'
 
     run_log = run_script(script_list , out_folder, out_prefix )
+    out_log = run_log.copy()
 
     if log_sql != None : 
         if ['job_name','table_name' , 'da_tran_SQL'].sort() != list(log_sql.keys()).sort() :
@@ -57,13 +58,12 @@ def run_pipeline(script_list, out_folder = '', out_prefix = None, email_dict = {
         run_log['job_name'] = log_sql['job_name']
         run_log.astype('str').to_sql(log_sql['table_name'], con = log_sql['da_tran_SQL'].engine , if_exists = 'append', index = False)
         run_log = run_log.drop(['job_name'], axis = 1)
-        
 
-    if only_error  : 
+    if sending & only_error  : 
         if (run_log['run_result'] != 'OK').sum() == 0 : sending = False
         else : run_log = run_log[(run_log['run_result'] != 'OK')]
 
-    if notebook_attached : 
+    if sending & notebook_attached : 
         if attached_only_error : 
             attached = run_log[(run_log['run_result'] != 'OK') & (run_log['notebook_out'].str.len() > 0)]['notebook_out'].unique()
         else : 
@@ -72,7 +72,7 @@ def run_pipeline(script_list, out_folder = '', out_prefix = None, email_dict = {
         else : attached = list(attached)
     else : attached = None
     
-    if attached_log :
+    if sending & attached_log :
         file_name = 'LOG_{}.csv'.format(datetime.now().strftime('%Y_%m_%d_%H_%M'))
         run_log.to_csv(file_name,index = False)
         if attached == None : attached = [file_name]
@@ -85,6 +85,6 @@ def run_pipeline(script_list, out_folder = '', out_prefix = None, email_dict = {
         em = email_sender(email_dict['user'] , email_dict['password'] , email_dict['server'])
         em.send(email_dict['sendto'] , email_subject , run_output , attachment= attached)
 
-    if attached_log : os.remove(file_name)
+    if sending & attached_log : os.remove(file_name)
 
-    
\ No newline at end of file
+    return out_log  
\ No newline at end of file
